@@ -1,9 +1,8 @@
-from dataclasses import dataclass
-
+from reamber.base.Property import item_props
 from reamber.base.Timed import Timed
 
 
-@dataclass
+@item_props()
 class Note(Timed):
     """ A Note Object is a playable timed object
 
@@ -11,4 +10,7 @@ class Note(Timed):
 
     The naming convention is done this way to make it clear on what is a note, hit and hold.
     """
-    column: int = 0
+    _props = dict(column=['int', 0])
+
+    def __init__(self, offset: float, column: int, **kwargs):
+        super().__init__(offset=offset, column=column, **kwargs)
