@@ -1,35 +1,30 @@
-from dataclasses import dataclass
-
-from reamber.osu.OsuSampleSet import OsuSampleSet
-
+from reamber.base.Property import item_props
 
 class OsuTimingPointType:
     SV: int = 0
     Bpm: int = 1
 
-
-@dataclass
+@item_props()
 class OsuTimingPointMeta:
     """ Holds all metadata for every timing point object"""
 
-    sampleSet: int = OsuSampleSet.AUTO
-    sampleSetIndex: int = 0
-    volume: int = 50
-    kiai: bool = False
+    _props = dict(sample_set=['int', 0],
+                  sample_set_index=['int', 0],
+                  volume=['int', 0],
+                  kiai=['bool', False])
 
     @staticmethod
-    def isTimingPoint(s: str) -> bool or None:
+    def is_timing_point(s: str) -> bool:
         """ Checks whether if the string is a Timing Point/Bpm Obj"""
         t = s.split(",")
         if len(t) < 8:
-            return None
+            return False
         return t[6] == "1"
 
     @staticmethod
-    def isSliderVelocity(s: str) -> bool or None:
+    def is_slider_velocity(s: str) -> bool:
         """ Checks whether if the string is a SV Point/SV Obj """
         t = s.split(",")
         if len(t) < 8:
-            return None
+            return False
         return t[6] == "0"
-
