@@ -11,21 +11,21 @@ class TestCombine(unittest.TestCase):
         t = SvPkg([SvSequence([SvObj(0, 1.0), SvObj(100, 2.0)]),
                    SvSequence([SvObj(100, 3.0), SvObj(200, 4.0)]),
                    SvSequence([SvObj(150, 5.0), SvObj(300, 6.0)])])\
-            .combine(combineMethod=SvPkg.CombineMethod.DROP_BY_POINT, combineMethodWindow=1)
+            .combine(combine_method=SvPkg.CombineMethod.DROP_BY_POINT, combine_method_window=1)
 
         self.assertEqual(len(t), 5)
 
         t = SvPkg([SvSequence([SvObj(0, 1.0), SvObj(100, 2.0)]),
                    SvSequence([SvObj(100, 3.0), SvObj(200, 4.0)]),
                    SvSequence([SvObj(150, 5.0), SvObj(300, 6.0)])])\
-            .combine(combineMethod=SvPkg.CombineMethod.DROP_BY_BOUND, combineMethodWindow=1)
+            .combine(combine_method=SvPkg.CombineMethod.DROP_BY_BOUND, combine_method_window=1)
 
         self.assertEqual(len(t), 4)
 
         t = SvPkg([SvSequence([SvObj(0, 1.0), SvObj(100, 2.0)]),
                    SvSequence([SvObj(100, 3.0), SvObj(200, 4.0)]),
                    SvSequence([SvObj(150, 5.0), SvObj(300, 6.0)])])\
-            .combine(combineMethod=SvPkg.CombineMethod.IGNORE, combineMethodWindow=1)
+            .combine(combine_method=SvPkg.CombineMethod.IGNORE, combine_method_window=1)
 
         self.assertEqual(len(t), 6)
 
